@@ -6,6 +6,14 @@ from dateutil.tz import tzutc, tzlocal
 # default NDS server
 NDSSERVER = 'nds.ligo.caltech.edu:31200'
 
+NDSSERVER_ALIAS_MAP = {
+    None: NDSSERVER,
+    '': NDSSERVER,
+    'cit': NDSSERVER,
+    'lho': 'nds.ligo-wa.caltech.edu:31200',
+    'llo': 'nds.ligo-la.caltech.edu:31200',
+}
+
 
 # date/time formatting for GPS conversion
 if os.getenv('DATETIME_TZ') == 'LOCAL':
