@@ -601,12 +601,17 @@ class DataStore(QtCore.QObject):
             self.signal_data_retrieve_done.emit(signal)
 
     def active(self, tid=None):
+        """data retrieval activity status of store
+
+        Returns True or False depending on if the specified thread is
+        active, or if any thread is active if none specified.
+
+        """
         if tid:
             thread = self.threads.get(tid)
-            if thread:
-                return not thread.isFinished()
-            else:
+            if not thread:
                 return False
+            return not thread.isFinished()
         for thread in self.threads.values():
             if not thread.isFinished():
                 return True
@@ -614,7 +619,18 @@ class DataStore(QtCore.QObject):
 
     @property
     def online(self):
-        return self.active('online')
+        """online status of store
+
+        If online active returns the trend of online retrieval,
+        otherwise returns False.
+
+        """
+        thread = self.threads.get('online')
+        if not thread:
+            return False
+        if thread.isFinished():
+            return False
+        return thread.trend
 
     def terminate(self):
         logger.debug("TERMINATE")
