@@ -163,18 +163,21 @@ def fake_iterate(channels=None, stride=None, **kwargs):
 ##########
 
 
-_KWARGS = {
-    'gap_handler': nds2.STATIC_HANDLER_NAN,
-}
+def get_parameters():
+    params = nds2.parameters()
+    params.set('GAP_HANDLER', 'STATIC_HANDLER_NAN')
+    return params
 
 
 def iterate(channels, start_end, stride):
-    kwargs = dict(**_KWARGS)
-    kwargs['channels'] = channels
+    kwargs = {
+        'channels': channels,
+        'stride': stride,
+        'params': get_parameters(),
+    }
     if start_end:
         kwargs['gps_start'] = start_end[0]
         kwargs['gps_stop'] = start_end[1]
-    kwargs['stride'] = stride
     if os.getenv('NDSSERVER', '').lower() == 'fake':
         func = fake_iterate
     else:
@@ -185,10 +188,12 @@ def iterate(channels, start_end, stride):
 
 
 def fetch(channels, start_end):
-    kwargs = dict(**_KWARGS)
-    kwargs['channels'] = channels
-    kwargs['gps_start'] = start_end[0]
-    kwargs['gps_stop'] = start_end[1]
+    kwargs = {
+        'channels': channels,
+        'gps_start': start_end[0],
+        'gps_stop': start_end[1],
+        'params': get_parameters(),
+    }
     if os.getenv('NDSSERVER', '').lower() == 'fake':
         func = fake_fetch
     else:
