@@ -169,7 +169,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
         ##########
         # trend
 
-        self.trendSelectGroup = QtGui.QButtonGroup()
+        self.trendSelectGroup = QtWidgets.QButtonGroup()
         # NOTE: the numbers correspond to indices in TREND_OPTIONS
         self.trendSelectGroup.addButton(self.trendAutoSelect, 0)
         self.trendSelectGroup.addButton(self.trendRawSelect, 1)
@@ -619,7 +619,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
         self.data.request(trend, (start, end))
 
     def _fetch(self, **kwargs):
-        if QtGui.QApplication.keyboardModifiers() == Qt.ShiftModifier:
+        if QtWidgets.QApplication.keyboardModifiers() == Qt.ShiftModifier:
             self.data.reset()
         if 't0' in kwargs:
             t0 = kwargs['t0']
